# silico
[![Github release](https://img.shields.io/github/release/Dih5/silico.svg)](https://github.com/Dih5/silico/releases/latest)
[![PyPI](https://img.shields.io/pypi/v/silico.svg)](https://pypi.python.org/pypi/silico)

[![license MIT](https://img.shields.io/badge/license-MIT-blue.svg)](https://raw.githubusercontent.com/Dih5/silico/master/LICENSE.txt)

[![Documentation Status](https://readthedocs.org/projects/silico/badge/?version=latest)](http://silico.readthedocs.io/en/latest/?badge=latest)

Python package to handle in silico experiments


## Installation
Assuming you have a [Python3](https://www.python.org/) distribution with [pip](https://pip.pypa.io/en/stable/installing/):

```bash
pip3 install silico
```

## Command line interface
To run the command line interface see:
```bash
silico --help
```

If the bin is not in the path you can do instead:
```bash
python -m silico --help
```
